@@ -229,6 +229,10 @@ class ScatterLayerArtist(MatplotlibLayerArtist):
                 self.plot_artist.set_data([], [])
                 self.scatter_artist.set_offsets(np.zeros((0, 2)))
             else:
+
+                if getattr(self._viewer_state, 'using_degrees', False):
+                    x = np.radians(x)
+
                 self.density_artist.set_label(None)
                 if self._use_plot_artist():
                     # In this case we use Matplotlib's plot function because it has much
@@ -507,7 +511,9 @@ class ScatterLayerArtist(MatplotlibLayerArtist):
                 self.state.layer is None):
             return
 
-        changed = set() if force else self.pop_changed_properties()
+        # NOTE: we need to evaluate this even if force=True so that the cache
+        # of updated properties is up to date after this method has been called.
+        changed = self.pop_changed_properties()
 
         if force or len(changed & DATA_PROPERTIES) > 0:
             self._update_data()
